# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .template import Template

__all__ = ["TemplateListResponse"]


class TemplateListResponse(BaseModel):
    items: List[Template]

    next_cursor: Optional[str] = FieldInfo(alias="nextCursor", default=None)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .senders import (
    SendersResource,
    AsyncSendersResource,
    SendersResourceWithRawResponse,
    AsyncSendersResourceWithRawResponse,
    SendersResourceWithStreamingResponse,
    AsyncSendersResourceWithStreamingResponse,
)
from .contacts import (
    ContactsResource,
    AsyncContactsResource,
    ContactsResourceWithRawResponse,
    AsyncContactsResourceWithRawResponse,
    ContactsResourceWithStreamingResponse,
    AsyncContactsResourceWithStreamingResponse,
)
from .messages import (
    MessagesResource,
    AsyncMessagesResource,
    MessagesResourceWithRawResponse,
    AsyncMessagesResourceWithRawResponse,
    MessagesResourceWithStreamingResponse,
    AsyncMessagesResourceWithStreamingResponse,
)
from .templates import (
    TemplatesResource,
    AsyncTemplatesResource,
    TemplatesResourceWithRawResponse,
    AsyncTemplatesResourceWithRawResponse,
    TemplatesResourceWithStreamingResponse,
    AsyncTemplatesResourceWithStreamingResponse,
)
from .introspect import (
    IntrospectResource,
    AsyncIntrospectResource,
    IntrospectResourceWithRawResponse,
    AsyncIntrospectResourceWithRawResponse,
    IntrospectResourceWithStreamingResponse,
    AsyncIntrospectResourceWithStreamingResponse,
)

__all__ = [
    "MessagesResource",
    "AsyncMessagesResource",
    "MessagesResourceWithRawResponse",
    "AsyncMessagesResourceWithRawResponse",
    "MessagesResourceWithStreamingResponse",
    "AsyncMessagesResourceWithStreamingResponse",
    "TemplatesResource",
    "AsyncTemplatesResource",
    "TemplatesResourceWithRawResponse",
    "AsyncTemplatesResourceWithRawResponse",
    "TemplatesResourceWithStreamingResponse",
    "AsyncTemplatesResourceWithStreamingResponse",
    "SendersResource",
    "AsyncSendersResource",
    "SendersResourceWithRawResponse",
    "AsyncSendersResourceWithRawResponse",
    "SendersResourceWithStreamingResponse",
    "AsyncSendersResourceWithStreamingResponse",
    "ContactsResource",
    "AsyncContactsResource",
    "ContactsResourceWithRawResponse",
    "AsyncContactsResourceWithRawResponse",
    "ContactsResourceWithStreamingResponse",
    "AsyncContactsResourceWithStreamingResponse",
    "IntrospectResource",
    "AsyncIntrospectResource",
    "IntrospectResourceWithRawResponse",
    "AsyncIntrospectResourceWithRawResponse",
    "IntrospectResourceWithStreamingResponse",
    "AsyncIntrospectResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["SenderUpdateParams"]


class SenderUpdateParams(TypedDict, total=False):
    name: str

    set_as_default: Annotated[bool, PropertyInfo(alias="setAsDefault")]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .sender import Sender as Sender
from .channel import Channel as Channel
from .contact import Contact as Contact
from .message import Message as Message
from .template import Template as Template
from .line_type import LineType as LineType
from .message_type import MessageType as MessageType
from .message_status import MessageStatus as MessageStatus
from .message_content import MessageContent as MessageContent
from .message_response import MessageResponse as MessageResponse
from .whatsapp_category import WhatsappCategory as WhatsappCategory
from .sender_list_params import SenderListParams as SenderListParams
from .contact_list_params import ContactListParams as ContactListParams
from .message_list_params import MessageListParams as MessageListParams
from .message_send_params import MessageSendParams as MessageSendParams
from .message_react_params import MessageReactParams as MessageReactParams
from .sender_create_params import SenderCreateParams as SenderCreateParams
from .sender_list_response import SenderListResponse as SenderListResponse
from .sender_update_params import SenderUpdateParams as SenderUpdateParams
from .template_list_params import TemplateListParams as TemplateListParams
from .contact_list_response import ContactListResponse as ContactListResponse
from .contact_update_params import ContactUpdateParams as ContactUpdateParams
from .message_content_param import MessageContentParam as MessageContentParam
from .message_list_response import MessageListResponse as MessageListResponse
from .template_create_params import TemplateCreateParams as TemplateCreateParams
from .template_list_response import TemplateListResponse as TemplateListResponse
from .introspect_validate_phone_params import IntrospectValidatePhoneParams as IntrospectValidatePhoneParams
from .introspect_validate_phone_response import IntrospectValidatePhoneResponse as IntrospectValidatePhoneResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["Sender"]


class Sender(BaseModel):
    id: str

    name: str

    phone_number: str = FieldInfo(alias="phoneNumber")
    """Phone number in E.164 format."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)

    is_default: Optional[bool] = FieldInfo(alias="isDefault", default=None)
    """Whether this sender is the project's default."""

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
